@@ -1,24 +1,87 @@
 #' Build articles section
 #'
 #' @description
-#' Each R Markdown vignette in `vignettes/` and its subdirectories is rendered
-#' and saved to `articles/`.
+#' `build_articles()` renders each R Markdown file underneath `vignettes/` and
+#' saves it to `articles/`. There are two exceptions:
 #'
-#' The only exception are `.Rmd` vignettes that start with `_` (i.e., `_index.Rmd`), enabling the use of child documents in [bookdown](https://bookdown.org/yihui/bookdown/), and vignettes in a `tutorials` subdirectory, which is reserved for tutorials built with `build_tutorials()`
+#' * Files that start with `_` (e.g., `_index.Rmd`) are ignored,
+#'   enabling the use of child documents in
+#'   [bookdown](https://bookdown.org/yihui/bookdown/)
 #'
-#' Vignettes are rendered using a special document
-#' format that reconciles [rmarkdown::html_document()] with your pkgdown
-#' template.
+#' * Files in `vignettes/tutorials` are handled by [build_tutorials()]
 #'
-#' Note that when run by itself (i.e. not by `build_site()`), vignettes will
-#' use a previous installed version of the package, not the current source
-#' version.
+#' Vignettes are rendered using a special document format that reconciles
+#' [rmarkdown::html_document()] with the pkgdown template. This means articles
+#' behave slightly differently to vignettes, particularly with respect to
+#' external files, and custom output formats. See below for more details.
 #'
-#' @section Get started vignette:
-#' A vignette with the same name as the package (e.g., `vignettes/pkgdown.Rmd`)
-#' gets special treatment. It is rendered and linked to in the navbar under
-#' "Get started". Rmarkdown files in `vignettes/tutorials/` are ignored,
-#' because these are assumed to contain tutorials, see `build_tutorials()`.
+#' Note that when you run `build_articles()` directly (outside of
+#' [build_site()]) vignettes will use the currently installed version of the
+#' package, not the current source version. This makes iteration quicker when
+#' you are primarily working on the text of an article.
+#'
+#' @section Index and navbar:
+#' You can control the articles index and navbar with a `articles` section in
+#' your `_pkgdown.yaml`. It defines a list of sections, eaach of which
+#' can contain four fields:
+#'
+#' * `title` (required): title of section, which appears as a heading on the
+#'   articles index.
+#'
+#' * `desc` (optional): An optional markdown description displayed underneath
+#'   the section title.
+#'
+#' * `navbar` (optional): A couple of words used to label this section in
+#'   the navbar. If omitted, this section of vignettes will not appear in the
+#'   navbar.
+#'
+#' * `contents` (required): a list of article names to include in the
+#'   section. This can either be names of individual vignettes or a
+#'   call to `starts_with()`. The name of a vignette includes its
+#'   path under `vignettes` without extension so that the name of the vignette
+#'   found at `vignettes/pizza/slice.Rmd` is `pizza/slice`.
+#'
+#' The title and description of individual vignettes displayed on the index
+#' comes from `title` and `description` fields of the YAML header in the Rmds.
+#'
+#' For example, this yaml might be used for some version of dplyr:
+#'
+#' ```
+#' articles:
+#' - title: Main verbs
+#'   navbar: ~
+#'   contents:
+#'   - one-table
+#'   - two-table
+#'   - rowwise
+#'   - colwise
+#'
+#' - title: Developer
+#'   desc: Vignettes aimed at package developers
+#'   contents:
+#'   - programming
+#'   - packages
+#' ```
+#'
+#' Note the use of the `navbar` fields. `navbar: ~` means that the "Main verbs"
+#' will appear in the navbar without a heading; the absence of the `navbar`
+#' field in the for the developer vignettes means that they will only be
+#' accessible via the articles index.
+#'
+#' ## Special links
+#'
+#' * A vignette with the same name as the package (e.g.,
+#'   `vignettes/pkgdown.Rmd` or `vignettes/articles/pkgdown.Rmd`)
+#'   automatically becomes a top-level "Get started" link, and will not appear
+#'   in the articles drop-down. (If your package name include a `.`, e.g.
+#'   `pack.down`, use a `-` in the vignette name, e.g. `pack.down.Rmd`.)
+#'
+#' * The navbar will include a link to the articles index if one or more
+#'   vignettes are not available through the navbar. If some vignettes appear
+#'   in the navbar drop-down list and others do not, the list will automatically
+#'   include a "More ..." link at the bottom; if no vignettes appear in the
+#'   the navbar, it will link directly to the articles index instead of
+#'   providing a drop-down.
 #'
 #' @section External files:
 #' pkgdown differs from base R in its handling of external files. When building
@@ -50,36 +113,6 @@
 #' See <https://github.com/r-lib/pkgdown/issues/838#issuecomment-430473856> for
 #' some hints on how to customise the appearance with CSS.
 #'
-#' @section YAML config:
-#' To tweak the index page, you need a section called `articles`,
-#' which provides a list of sections containing, a `title`, list of
-#' `contents`, and optional `description`.
-#'
-#' For example, this imaginary file describes some of the structure of
-#' the [R markdown articles](http://rmarkdown.rstudio.com/articles.html):
-#'
-#' ```
-#' articles:
-#' - title: R Markdown
-#'   contents:
-#'   - starts_with("authoring")
-#' - title: Websites
-#'   contents:
-#'   - rmarkdown_websites
-#'   - rmarkdown_site_generators
-#' ```
-#'
-#' Note that `contents` can contain either a list of vignette names
-#' (including subdirectories), or if the functions in a section share a
-#' common prefix or suffix, you can use `starts_with("prefix")` and
-#' `ends_with("suffix")` to select them all. If you don't care about
-#' position within the string, use `contains("word")`. For more complex
-#' naming schemes you can use an arbitrary regular expression with
-#' `matches("regexp")`.
-#'
-#' pkgdown will check that all vignettes are included in the index
-#' this page, and will generate a warning if you have missed any.
-#'
 #' @section YAML header:
 #' By default, pkgdown builds all articles with [rmarkdown::html_document()]
 #' by setting the `template` parameter. This overrides any custom settings
@@ -116,10 +149,6 @@
 #' present: if you do not want this, you will need to customise the navbar. See
 #' [build_site()] details.
 #'
-#' Vignette files prefixed with an underscore (e.g., `_index.Rmd`) are ignored
-#' to enable rendering of [bookdown](https://bookdown.org/yihui/bookdown/)
-#' sites.
-#'
 #' @section Tables of contents:
 #' You can control the TOC depth via the YAML configuration file:
 #'
@@ -196,11 +225,16 @@ build_article <- function(name,
   scoped_file_context(depth = depth)
 
   front <- rmarkdown::yaml_front_matter(input_path)
+  # Take opengraph from article's yaml front matter
+  front_opengraph <- check_open_graph(front$opengraph %||% list())
+  data$opengraph <- utils::modifyList(
+    data$opengraph %||% list(), front_opengraph
+  )
 
   default_data <- list(
     pagetitle = front$title,
-    opengraph = list(description = "$description$"),
-    source = github_source_links(pkg$github_url, path_rel(input, pkg$src_path)),
+    opengraph = list(description = front$description %||% pkg$package),
+    source = repo_source(pkg, path_rel(input, pkg$src_path)),
     filename = path_file(input)
   )
   data <- utils::modifyList(default_data, data)
@@ -284,6 +318,8 @@ rmarkdown_template <- function(pkg, name, data, depth) {
 # Articles index ----------------------------------------------------------
 
 build_articles_index <- function(pkg = ".") {
+  pkg <- as_pkgdown(pkg)
+
   dir_create(path(pkg$dst_path, "articles"))
   render_page(
     pkg,
@@ -340,7 +376,8 @@ data_articles_index_section <- function(section, pkg) {
   contents <- tibble::tibble(
     name = section_vignettes$name,
     path = path_rel(section_vignettes$file_out, "articles"),
-    title = section_vignettes$title
+    title = section_vignettes$title,
+    description = lapply(section_vignettes$description, markdown_text),
   )
 
   list(
@@ -372,5 +409,9 @@ default_articles_index <- function(pkg = ".") {
       contents = paste0("`", pkg$vignettes$name, "`")
     )
   ))
+}
 
+article_is_intro <- function(name, package) {
+  package <- gsub(".", "-", package, fixed = TRUE)
+  name %in% c(package, paste0("articles/", package))
 }
