@@ -3,7 +3,7 @@ has_citation <- function(path = ".") {
   file_exists(path(path, 'inst/CITATION'))
 }
 
-create_meta <- function(path) {
+create_citation_meta <- function(path) {
   path <- path(path, "DESCRIPTION")
 
   dcf <- read.dcf(path)
@@ -11,6 +11,8 @@ create_meta <- function(path) {
 
   if (!is.null(meta$Encoding)) {
     meta <- lapply(meta, iconv, from = meta$Encoding, to = "UTF-8")
+  } else {
+    meta$Encoding <- "UTF-8"
   }
 
   meta
@@ -20,7 +22,7 @@ read_citation <- function(path = ".") {
   if (!has_citation(path)) {
     return(character())
   }
-  meta <- create_meta(path)
+  meta <- create_citation_meta(path)
   cit_path <- path(path, 'inst/CITATION')
 
   utils::readCitationFile(cit_path, meta = meta)
@@ -42,16 +44,26 @@ data_citations <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
   cit <- read_citation(pkg$src_path)
 
-  list(
-    html = format(cit, style = "html"),
-    bibtex = format(cit, style = "bibtex")
-  ) %>% purrr::transpose()
+  text_version <- format(cit, style = "textVersion")
+  if (text_version == "") {
+    cit <- list(
+      html = format(cit, style = "html"),
+      bibtex = format(cit, style = "bibtex")
+    )
+  } else {
+    cit <- list(
+      html = paste0("<p>",text_version, "</p>"),
+      bibtex = format(cit, style = "bibtex")
+    )
+  }
+
+   purrr::transpose(cit)
 }
 
 build_citation_authors <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
 
-  source <- github_source_links(pkg$github_url, "inst/CITATION")
+  source <- repo_source(pkg, "inst/CITATION")
 
   data <- list(
     pagetitle = "Citation and Authors",
