@@ -13,11 +13,15 @@ topic_index <- function(package) {
   }
 }
 
-topic_index_local <- memoise(function(package, path = find.package(package)) {
+topic_index_local <- memoise(function(package, path = NULL) {
   if (!is_installed(package)) {
     return(character())
   }
 
+  if (is.null(path)) {
+    path <- find.package(package)
+  }
+
   rd <- package_rd(path)
   aliases <- purrr::map(rd, extract_tag, "tag_alias")
   names(aliases) <- gsub("\\.Rd$", "", names(rd))
