@@ -3,9 +3,9 @@ markdown <- function(path = NULL, ..., strip_header = FALSE) {
   on.exit(file_delete(tmp), add = TRUE)
 
   if (rmarkdown::pandoc_available("2.0")) {
-    from <- "markdown_github-hard_line_breaks+smart+auto_identifiers"
+    from <- "markdown_github-hard_line_breaks+smart+auto_identifiers+tex_math_dollars+tex_math_single_backslash+markdown_in_html_blocks"
   } else if (rmarkdown::pandoc_available("1.12.3")) {
-    from <- "markdown_github-hard_line_breaks"
+    from <- "markdown_github-hard_line_breaks+tex_math_dollars+tex_math_single_backslash"
   } else {
     stop("Pandoc not available", call. = FALSE)
   }
@@ -58,8 +58,10 @@ markdown <- function(path = NULL, ..., strip_header = FALSE) {
 }
 
 markdown_text <- function(text, ...) {
-  if (is.null(text))
-    return(text)
+  if (identical(text, NA_character_) || is.null(text)) {
+    return(NULL)
+  }
+
 
   tmp <- tempfile()
   on.exit(unlink(tmp), add = TRUE)
