@@ -329,7 +329,7 @@ as_html.tag_enumerate <- function(x, ...) {
 }
 #' @export
 as_html.tag_describe <- function(x, ...) {
-  paste0("<dl class='dl-horizontal'>\n", parse_descriptions(x[-1], ...), "\n</dl>")
+  paste0("<dl'>\n", parse_descriptions(x[-1], ...), "\n</dl>")
 }
 
 # Effectively does nothing: only used by parse_items() to split up
@@ -421,6 +421,15 @@ as_html.tag_code <-         function(x, ..., auto_link = TRUE) {
   href <- href_expr(expr)
   paste0("<code>", a(text, href = href), "</code>")
 }
+
+#' @export
+as_html.tag_preformatted <- function(x, ...) {
+  text <- flatten_text(x, ...)
+  # highlight_text() does nothing if not parseable
+  paste0("<pre>", highlight_text(text), "</pre>")
+}
+
+
 #' @export
 as_html.tag_kbd <-          tag_wrapper("<kbd>", "</kbd>")
 #' @export
@@ -442,9 +451,6 @@ as_html.tag_option <-       tag_wrapper('<span class="option">',"</span>")
 #' @export
 as_html.tag_command <-      tag_wrapper("<code class='command'>", "</code>")
 
-#' @export
-as_html.tag_preformatted <- tag_wrapper('<pre>','</pre>')
-
 #' @export
 as_html.tag_dfn <-          tag_wrapper("<dfn>", "</dfn>")
 #' @export
