@@ -1,7 +1,8 @@
 context("test-highlight.R")
 
 test_that("can link to external topics that use ::", {
-  scoped_package_context("test")
+  scoped_package_context("test", c(foo = "bar"))
+  scoped_file_context("test")
 
   # Functions
   expect_equal(
@@ -14,6 +15,12 @@ test_that("can link to external topics that use ::", {
     highlight_text("MASS::addterm"),
     "<span class='kw pkg'>MASS</span><span class='kw ns'>::</span><span class='no'><a href='https://rdrr.io/pkg/MASS/man/addterm.html'>addterm</a></span>"
   )
+
+  # Local package gets local link
+  expect_equal(
+    highlight_text("test::foo()"),
+    "<span class='kw pkg'>test</span><span class='kw ns'>::</span><span class='fu'><a href='bar.html'>foo</a></span>()"
+  )
 })
 
 test_that("can link to implicit remote topics with library()", {
